@@ -94,7 +94,7 @@ extern int optind;
  /*
   * FreeBSD can handle filesystems > 2GB.
   */
-#if defined(FREEBSD2) || defined(FREEBSD3) || defined(FREEBSD4) 
+#if defined(FREEBSD2) || defined(FREEBSD3) || defined(FREEBSD4) || defined(FREEBSD5)
 #define SUPPORTED
 #define LSEEK		lseek
 #define OFF_T		off_t
@@ -119,6 +119,21 @@ extern int optind;
 #define HAVE_TIMEZONE	1
 #endif /* BSDI */
 
+/*
+ * NetBSD
+ */
+#if defined(NETBSD16)
+#define SUPPORTED
+#define LSEEK		lseek
+#define OFF_T		off_t
+#define STRTOUL		strtoul
+#define DADDR_T		daddr_t
+#define DEF_FSTYPE	"netbsd"
+#define INO_TO_CG	ino_to_cg
+#define HAVE_TIMEZONE	0
+#endif /* NETBSD */
+
+
  /*
   * OpenBSD looks like BSD/OS 3.x.
   */
@@ -174,7 +189,7 @@ extern int optind;
 #define roundup(x, y)	\
 	( ( ((x)+((y) - 1)) / (y)) * (y) )
 
-#endif /* FREEBSD */
+#endif /* CYGWIN */
 
 
 
